@@ -8,16 +8,17 @@ import inspect
 import os
 from pkg_resources import resource_filename
 import warnings
+import urllib.request
 import itertools
 
 import astropy.table as at
 import astropy.io.votable as vo
 import astropy.units as q
 from astropy.utils.exceptions import AstropyWarning
-from astroquery.svo_fps import SvoFps
 from bokeh.plotting import figure, show
 import bokeh.palettes as bpal
 import numpy as np
+from .utils import incremented_monotonic
 
 
 warnings.simplefilter('ignore', category=AstropyWarning)
@@ -94,7 +95,8 @@ class Filter:
         The SVO filter ID
 
     """
-    def __init__(self, band, filter_directory=None, wave_units=q.um, flux_units=q.erg/q.s/q.cm**2/q.AA, **kwargs):
+    def __init__(self, band, filter_directory=None, wave_units=q.um, flux_units=q.erg/q.s/q.cm**2/q.AA, 
+        monotonic=True, **kwargs):
         """
         Loads the bandpass data into the Filter object
 
@@ -108,10 +110,16 @@ class Filter:
             The wavelength units
         flux_units: str, astropy.units.core.PrefixUnit  (optional)
             The zeropoint flux units
+        monotonic: bool
+            Default = True. Whether to add a small offset to repeated elements in wavelength array 
+            to ensure montonically increasing wavelengths.
         """
         if filter_directory is None:
             filter_directory = resource_filename('svo_filters', 'data/filters/')
 
+        # Whether to ensure wavelengths returned should be strictly monotonically increasing.
+        self.monotonic = monotonic 
+        
         # Check if TopHat
         if band.lower().replace('-', '').replace(' ', '') == 'tophat':
 
@@ -126,6 +134,7 @@ class Filter:
             else:
                 # Load the filter
                 n_pix = kwargs.get('n_pixels', 100)
+                self.monotonic = False #  Never ensure monotonic for tophat as that can mess up a tophat profile?
                 self.load_TopHat(wave_min, wave_max, n_pix)
 
         else:
@@ -160,19 +169,21 @@ class Filter:
             # Otherwise try a Web query or throw an error
             else:
               
-                err = """No filters match {}\n\nFILTERS ON FILE: {}\n\nA full list of available filters from the\nSVO Filter Profile Service can be found at\nhttp: //svo2.cab.inta-csic.es/theory/fps3/\n\nTry again with the desired filter as '<facility>/<instrument>.<filter_name>', e.g. '2MASS/2MASS.J'""".format(band, ', '.join(bands))
+                err = f"No filters match {band}\n\nFILTERS ON FILE: \n\nFILTERS ON FILE: {', '.join(bands)}\n\n" 
+                "A full list of available filters from the\nSVO Filter Profile Service can be found at\n"
+                "http: //svo2.cab.inta-csic.es/theory/fps3/\n\nTry again with the desired filter as " 
+                "'<facility>/<instrument>.<filter_name>', e.g. '2MASS/2MASS.J'"
+
+                # Valid SVO filter names have backslash
+                if '/' not in band:
+                    raise IndexError(err)
 
                 # Try a web query
-                if '/' in band:
-                    try:
-                        self.load_web(band)
-                    except:
-                        raise IndexError(err)
-                
-                else:
-                    
-                    # Or throw an error
+                try:
+                    self.load_web(band)
+                except IndexError:
                     raise IndexError(err)
+                # Make sure we return e.g. Connection Error, but are not catching e.g. SysExit calls.
 
         # Set the wavelength and throughput
         self._wave_units = q.AA
@@ -184,20 +195,20 @@ class Filter:
         self.pixels_per_bin = self.raw.shape[-1]
 
         # Rename some values and apply units
-        self.wave_min = self.WavelengthMin * self.wave_units
-        self.wave_max = self.WavelengthMax * self.wave_units
-        self.wave_eff = self.WavelengthEff * self.wave_units
-        self.wave_center = self.WavelengthCen * self.wave_units
-        self.wave_mean = self.WavelengthMean * self.wave_units
-        self.wave_peak = self.WavelengthPeak * self.wave_units
+        self.wave_min = float(self.WavelengthMin) * self.wave_units
+        self.wave_max = float(self.WavelengthMax) * self.wave_units
+        self.wave_eff = float(self.WavelengthEff) * self.wave_units
+        self.wave_center = float(self.WavelengthCen) * self.wave_units
+        self.wave_mean = float(self.WavelengthMean) * self.wave_units
+        self.wave_peak = float(self.WavelengthPeak) * self.wave_units
         self.thru_peak = self.raw[1].max()
-        self.wave_phot = self.WavelengthPhot * self.wave_units
-        self.wave_pivot = self.WavelengthPivot * self.wave_units
-        self.width_eff = self.WidthEff * self.wave_units
-        self.fwhm = self.FWHM * self.wave_units
-        self.hm_x1 *= self.wave_units
-        self.hm_x2 *= self.wave_units
-        self.zp = self.ZeroPoint * q.Unit(self.ZeroPointUnit)
+        self.wave_phot = float(self.WavelengthPhot) * self.wave_units
+        self.wave_pivot = float(self.WavelengthPivot) * self.wave_units
+        self.width_eff = float(self.WidthEff) * self.wave_units
+        self.fwhm = float(self.FWHM) * self.wave_units
+        self.hm_x1 = float(self.hm_x1) * self.wave_units
+        self.hm_x2 = float(self.hm_x2) * self.wave_units
+        self.zp = float(self.ZeroPoint) * q.Unit(self.ZeroPointUnit)
 
         # Delete redundant attributes
         del self.WavelengthMin, self.WavelengthMax, self.WavelengthEff
@@ -562,15 +573,20 @@ class Filter:
         filt: str
             The '<facility>/<instrument>.<filter_name>' of the filter, e.g. '2MASS/2MASS.J'
         """
-        # Get the transmission data for the filter
-        data = SvoFps.get_transmission_data(filt)
+        # Download XML file
+        url = 'http://svo2.cab.inta-csic.es/theory/fps/fps.php?ID={}'.format(filt)
 
-        # Make into arrays
-        self.raw = np.array([np.array(data['Wavelength']), np.array(data['Transmission'])])
+        # Temp filename
+        filename = filt.replace('/', '_')
 
-        # Load it into the object
-        self.filterID = filt
-        self.load_raw(wave_units=str(data['Wavelength'].unit))
+        # Download the XML file from SVO Filter Profile Service
+        urllib.request.urlretrieve(url, filename)
+
+        # Load the XML file
+        self.load_xml(filename)
+
+        # Delete the temp file
+        os.remove(filename)
 
     def load_xml(self, filepath):
         """Load the filter from a txt file
@@ -725,6 +741,9 @@ class Filter:
         else:
             return fig
 
+
+    
+
     @property
     def rsr(self):
         """A getter for the relative spectral response (rsr) curve"""
@@ -755,6 +774,10 @@ class Filter:
     @property
     def wave(self):
         """A getter for the wavelength"""
+        # Check wavelength is monotonically increasing
+        
+        if self.monotonic:
+            self._wave = incremented_monotonic(self._wave, increment_step=1000)
         return self._wave
 
     @wave.setter
